@@ -22,8 +22,8 @@ pub use crate::context;
 type ServiceFuture = BoxFuture<'static, Result<Response<Body>, crate::ServiceError>>;
 
 use crate::{Api,
+     AddStudentResponse,
      DeleteStudentResponse,
-     AddstudentResponse,
      UpdateStudentResponse,
      GetStudentByIdResponse,
      GetStudentsResponse
@@ -159,6 +159,100 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
 
         match &method {
 
+            // AddStudent - POST /mutation-api/student-service/students
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS) => {
+                {
+                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
+                        &Some(ref authorization) => authorization,
+                        &None => return Ok(Response::builder()
+                                                .status(StatusCode::FORBIDDEN)
+                                                .body(Body::from("Unauthenticated"))
+                                                .expect("Unable to create Authentication Forbidden response")),
+                    };
+                }
+
+                // Body parameters (note that non-required body parameters will ignore garbage
+                // values, rather than causing a 400 response). Produce warning header and logs for
+                // any unused fields.
+                let result = body.to_raw().await;
+                match result {
+                            Ok(body) => {
+                                let mut unused_elements = Vec::new();
+                                let param_student: Option<models::Student> = if !body.is_empty() {
+                                    let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
+                                    match serde_ignored::deserialize(deserializer, |path| {
+                                            warn!("Ignoring unknown field in body: {}", path);
+                                            unused_elements.push(path.to_string());
+                                    }) {
+                                        Ok(param_student) => param_student,
+                                        Err(e) => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from(format!("Couldn't parse body parameter Student - doesn't match schema: {}", e)))
+                                                        .expect("Unable to create Bad Request response for invalid body parameter Student due to schema")),
+                                    }
+                                } else {
+                                    None
+                                };
+                                let param_student = match param_student {
+                                    Some(param_student) => param_student,
+                                    None => return Ok(Response::builder()
+                                                        .status(StatusCode::BAD_REQUEST)
+                                                        .body(Body::from("Missing required body parameter Student"))
+                                                        .expect("Unable to create Bad Request response for missing body parameter Student")),
+                                };
+
+                                let result = api_impl.add_student(
+                                            param_student,
+                                        &context
+                                    ).await;
+                                let mut response = Response::new(Body::empty());
+                                response.headers_mut().insert(
+                                            HeaderName::from_static("x-span-id"),
+                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
+                                                .expect("Unable to create X-Span-ID header value"));
+
+                                        if !unused_elements.is_empty() {
+                                            response.headers_mut().insert(
+                                                HeaderName::from_static("warning"),
+                                                HeaderValue::from_str(format!("Ignoring unknown fields in body: {:?}", unused_elements).as_str())
+                                                    .expect("Unable to create Warning header value"));
+                                        }
+
+                                        match result {
+                                            Ok(rsp) => match rsp {
+                                                AddStudentResponse::SuccessfulOperation
+                                                    (body)
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
+                                                    response.headers_mut().insert(
+                                                        CONTENT_TYPE,
+                                                        HeaderValue::from_str("application/json")
+                                                            .expect("Unable to create Content-Type header for ADD_STUDENT_SUCCESSFUL_OPERATION"));
+                                                    let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
+                                                    *response.body_mut() = Body::from(body);
+                                                },
+                                                AddStudentResponse::InvalidInput
+                                                => {
+                                                    *response.status_mut() = StatusCode::from_u16(405).expect("Unable to turn 405 into a StatusCode");
+                                                },
+                                            },
+                                            Err(_) => {
+                                                // Application code returned an error. This should not happen, as the implementation should
+                                                // return a valid response.
+                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
+                                                *response.body_mut() = Body::from("An internal error occurred");
+                                            },
+                                        }
+
+                                        Ok(response)
+                            },
+                            Err(e) => Ok(Response::builder()
+                                                .status(StatusCode::BAD_REQUEST)
+                                                .body(Body::from(format!("Couldn't read body parameter Student: {}", e)))
+                                                .expect("Unable to create Bad Request response due to unable to read body parameter Student")),
+                        }
+            },
+
             // DeleteStudent - DELETE /mutation-api/student-service/students/{id}
             &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS_ID) => {
                 {
@@ -230,100 +324,6 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                         Ok(response)
             },
 
-            // Addstudent - POST /mutation-api/student-service/students
-            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS) => {
-                {
-                    let authorization = match (&context as &dyn Has<Option<Authorization>>).get() {
-                        &Some(ref authorization) => authorization,
-                        &None => return Ok(Response::builder()
-                                                .status(StatusCode::FORBIDDEN)
-                                                .body(Body::from("Unauthenticated"))
-                                                .expect("Unable to create Authentication Forbidden response")),
-                    };
-                }
-
-                // Body parameters (note that non-required body parameters will ignore garbage
-                // values, rather than causing a 400 response). Produce warning header and logs for
-                // any unused fields.
-                let result = body.to_raw().await;
-                match result {
-                            Ok(body) => {
-                                let mut unused_elements = Vec::new();
-                                let param_student: Option<models::Student> = if !body.is_empty() {
-                                    let deserializer = &mut serde_json::Deserializer::from_slice(&*body);
-                                    match serde_ignored::deserialize(deserializer, |path| {
-                                            warn!("Ignoring unknown field in body: {}", path);
-                                            unused_elements.push(path.to_string());
-                                    }) {
-                                        Ok(param_student) => param_student,
-                                        Err(e) => return Ok(Response::builder()
-                                                        .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from(format!("Couldn't parse body parameter Student - doesn't match schema: {}", e)))
-                                                        .expect("Unable to create Bad Request response for invalid body parameter Student due to schema")),
-                                    }
-                                } else {
-                                    None
-                                };
-                                let param_student = match param_student {
-                                    Some(param_student) => param_student,
-                                    None => return Ok(Response::builder()
-                                                        .status(StatusCode::BAD_REQUEST)
-                                                        .body(Body::from("Missing required body parameter Student"))
-                                                        .expect("Unable to create Bad Request response for missing body parameter Student")),
-                                };
-
-                                let result = api_impl.addstudent(
-                                            param_student,
-                                        &context
-                                    ).await;
-                                let mut response = Response::new(Body::empty());
-                                response.headers_mut().insert(
-                                            HeaderName::from_static("x-span-id"),
-                                            HeaderValue::from_str((&context as &dyn Has<XSpanIdString>).get().0.clone().to_string().as_str())
-                                                .expect("Unable to create X-Span-ID header value"));
-
-                                        if !unused_elements.is_empty() {
-                                            response.headers_mut().insert(
-                                                HeaderName::from_static("warning"),
-                                                HeaderValue::from_str(format!("Ignoring unknown fields in body: {:?}", unused_elements).as_str())
-                                                    .expect("Unable to create Warning header value"));
-                                        }
-
-                                        match result {
-                                            Ok(rsp) => match rsp {
-                                                AddstudentResponse::SuccessfulOperation
-                                                    (body)
-                                                => {
-                                                    *response.status_mut() = StatusCode::from_u16(200).expect("Unable to turn 200 into a StatusCode");
-                                                    response.headers_mut().insert(
-                                                        CONTENT_TYPE,
-                                                        HeaderValue::from_str("application/json")
-                                                            .expect("Unable to create Content-Type header for ADDSTUDENT_SUCCESSFUL_OPERATION"));
-                                                    let body = serde_json::to_string(&body).expect("impossible to fail to serialize");
-                                                    *response.body_mut() = Body::from(body);
-                                                },
-                                                AddstudentResponse::InvalidInput
-                                                => {
-                                                    *response.status_mut() = StatusCode::from_u16(405).expect("Unable to turn 405 into a StatusCode");
-                                                },
-                                            },
-                                            Err(_) => {
-                                                // Application code returned an error. This should not happen, as the implementation should
-                                                // return a valid response.
-                                                *response.status_mut() = StatusCode::INTERNAL_SERVER_ERROR;
-                                                *response.body_mut() = Body::from("An internal error occurred");
-                                            },
-                                        }
-
-                                        Ok(response)
-                            },
-                            Err(e) => Ok(Response::builder()
-                                                .status(StatusCode::BAD_REQUEST)
-                                                .body(Body::from(format!("Couldn't read body parameter Student: {}", e)))
-                                                .expect("Unable to create Bad Request response due to unable to read body parameter Student")),
-                        }
-            },
-
             // UpdateStudent - PUT /mutation-api/student-service/students/{id}
             &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS_ID) => {
                 {
@@ -644,6 +644,23 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                     },
                     None => None,
                 };
+                let param_polity_name = query_params.iter().filter(|e| e.0 == "polityName").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_polity_name = match param_polity_name {
+                    Some(param_polity_name) => {
+                        let param_polity_name =
+                            <String as std::str::FromStr>::from_str
+                                (&param_polity_name);
+                        match param_polity_name {
+                            Ok(param_polity_name) => Some(param_polity_name),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter polityName - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter polityName")),
+                        }
+                    },
+                    None => None,
+                };
                 let param_sorts = query_params.iter().filter(|e| e.0 == "sorts").map(|e| e.1.to_owned())
                     .filter_map(|param_sorts| param_sorts.parse().ok())
                     .collect::<Vec<_>>();
@@ -694,6 +711,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                             param_undergraduate_school,
                                             param_date_of_birth,
                                             param_place_of_birth,
+                                            param_polity_name,
                                             param_sorts.as_ref(),
                                             param_offset,
                                             param_count,
@@ -755,10 +773,10 @@ impl<T> RequestParser<T> for ApiRequestParser {
     fn parse_operation_id(request: &Request<T>) -> Result<&'static str, ()> {
         let path = paths::GLOBAL_REGEX_SET.matches(request.uri().path());
         match request.method() {
+            // AddStudent - POST /mutation-api/student-service/students
+            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS) => Ok("AddStudent"),
             // DeleteStudent - DELETE /mutation-api/student-service/students/{id}
             &hyper::Method::DELETE if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS_ID) => Ok("DeleteStudent"),
-            // Addstudent - POST /mutation-api/student-service/students
-            &hyper::Method::POST if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS) => Ok("Addstudent"),
             // UpdateStudent - PUT /mutation-api/student-service/students/{id}
             &hyper::Method::PUT if path.matched(paths::ID_MUTATION_API_STUDENT_SERVICE_STUDENTS_ID) => Ok("UpdateStudent"),
             // GetStudentById - GET /query-api/student-service/students/{id}
